jQuery( document ).ready( function ( $ ) {
    "use strict";

    /** -------------------------------------------------------------------------------
     *                      s h o w   a n d   h i d e   F I E L D S
     * -------------------------------------------------------------------------------- */
    var show_if_customer_chooses_blocks = $( '.show_if_customer_chooses_blocks' ),
        show_if_can_be_cancelled        = $( '.show_if_can_be_cancelled' ),
        show_if_customer_one_day        = $( '.show_if_customer_one_day' ),
        show_if_booking_has_persons     = $( '.show_if_booking_has_persons' );

    // show TAX if product is Booking
    $( document ).find( '._tax_status_field' ).closest( 'div' ).addClass( 'show_if_' + wcbk_admin.prod_type );
    // hide option shipping in tax if product is Booking
    $( document ).find( '#_tax_status > option[value="shipping"]' ).addClass( 'hide_if_' + wcbk_admin.prod_type );
    // trigger change to product type select to call WC show_and_hide_panels()
    $( 'select#product-type' ).trigger( 'change' );

    // Booking Min Max Duration
    $( 'select#_yith_booking_duration_type' ).on( 'change', function () {
        if ( $( this ).val() == 'customer' ) {
            show_if_customer_chooses_blocks.show();
        } else {
            show_if_customer_chooses_blocks.hide();
        }
    } ).trigger( 'change' );

    // Booking Can be cancelled
    $( 'input#_yith_booking_can_be_cancelled' ).on( 'change', function () {
        if ( $( this ).is( ':checked' ) ) {
            show_if_can_be_cancelled.show();
        } else {
            show_if_can_be_cancelled.hide();
        }
    } ).trigger( 'change' );

    // Show enable calendar picker if customer one day
    $( document ).on( 'check_if_customer_one_day', function () {
        var duration_type = $( 'select#_yith_booking_duration_type' ).val(),
            duration      = $( 'input#_yith_booking_duration' ).val(),
            duration_unit = $( 'select#_yith_booking_duration_unit' ).val();

        if ( duration_type == 'customer' && duration == 1 && duration_unit == 'day' ) {
            show_if_customer_one_day.show();
        } else {
            show_if_customer_one_day.hide();
        }

    } ).trigger( 'check_if_customer_one_day' );

    $( document ).on( 'change', '#_yith_booking_duration_type, #_yith_booking_duration, #_yith_booking_duration_unit', function () {
        $( document ).trigger( 'check_if_customer_one_day' );
    } );

    // Booking has persons
    $( 'input#_yith_booking_has_persons' ).on( 'change', function () {
        if ( $( this ).is( ':checked' ) ) {
            show_if_booking_has_persons.show();
        } else {
            show_if_booking_has_persons.hide();
        }
    } ).trigger( 'change' );


    /** -------------------------------------------------------------------------------
     *                               C O S T S   T A B L E
     * --------------------------------------------------------------------------------
     */
    var costs_table            = $( '#yith-wcbk-booking-costs-table' ),
        costs_default_row      = costs_table.find( 'tr.yith-wcbk-costs-default-row' ).first(),
        costs_add_range        = $( 'input#yith-wcbk-costs-add-range' ),
        costs_fields_container = $( '#' + costs_table.data( 'fields-container-id' ) ),
        costs_input            = costs_fields_container.find( '.yith-wcbk-admin-input-range' ),
        costs_number           = costs_fields_container.find( '.yith-wcbk-number-range' ),
        costs_monthselect      = costs_fields_container.find( '.yith-wcbk-month-range-select' ),
        costs_weekselect       = costs_fields_container.find( '.yith-wcbk-week-range-select' ),
        costs_dayselect        = costs_fields_container.find( '.yith-wcbk-day-range-select' ),
        datepickerFormat       = { dateFormat: 'yy-mm-dd' };

    costs_table.on( 'change', 'select.yith-wcbk-costs-range-type-select', function ( event ) {
            var select     = $( event.target ),
                row        = select.closest( 'tr' ),
                from       = row.find( 'td.yith-wcbk-costs-from' ),
                to         = row.find( 'td.yith-wcbk-costs-to' ),
                range_type = select.val();

            switch ( range_type ) {
                case 'custom':
                    from.html( costs_input.clone().addClass( 'yith-wcbk-admin-date-picker' ).attr( 'name', '_yith_booking_costs_range[from][]' ).datepicker( datepickerFormat ) );
                    to.html( costs_input.clone().addClass( 'yith-wcbk-admin-date-picker' ).attr( 'name', '_yith_booking_costs_range[to][]' ).datepicker( datepickerFormat ) );
                    break;
                case 'month':
                    from.html( costs_monthselect.clone().attr( 'name', '_yith_booking_costs_range[from][]' ) );
                    to.html( costs_monthselect.clone().attr( 'name', '_yith_booking_costs_range[to][]' ) );
                    break;
                case 'week':
                    from.html( costs_weekselect.clone().attr( 'name', '_yith_booking_costs_range[from][]' ) );
                    to.html( costs_weekselect.clone().attr( 'name', '_yith_booking_costs_range[to][]' ) );
                    break;
                case 'day':
                    from.html( costs_dayselect.clone().attr( 'name', '_yith_booking_costs_range[from][]' ) );
                    to.html( costs_dayselect.clone().attr( 'name', '_yith_booking_costs_range[to][]' ) );
                    break;
                case 'person':
                case 'block':
                    from.html( costs_number.clone().attr( 'name', '_yith_booking_costs_range[from][]' ) );
                    to.html( costs_number.clone().attr( 'name', '_yith_booking_costs_range[to][]' ) );
                    break;
                default:
                    from.html( costs_input.clone().attr( 'name', '_yith_booking_costs_range[from][]' ).yith_wcbk_timepicker() );
                    to.html( costs_input.clone().attr( 'name', '_yith_booking_costs_range[to][]' ).yith_wcbk_timepicker() );
                    break;
            }

        } )
        /* ----  D e l e t e   R o w  ---- */
        .on( 'click', '.yith-wcbk-delete', function ( event ) {
            var delete_btn = $( event.target ),
                target_row = delete_btn.closest( 'tr' );

            target_row.remove();
        } )

        /* ----  S o r t a b l e  ---- */
        .find( 'tbody' ).sortable( {
                                       items               : 'tr',
                                       cursor              : 'move',
                                       handle              : '.yith-wcbk-anchor',
                                       axis                : 'y',
                                       scrollSensitivity   : 40,
                                       forcePlaceholderSize: true,
                                       opacity             : 0.65,
                                       helper              : function ( e, tr ) {
                                           var originals = tr.children(),
                                               helper    = tr.clone();
                                           helper.children().each( function ( index ) {
                                               // Set helper cell sizes to match the original sizes
                                               $( this ).width( originals.eq( index ).width() );
                                           } );
                                           return helper;
                                       }
                                   } );

    costs_add_range.on( 'click', function () {
        var added_row = costs_default_row.clone().removeClass( 'yith-wcbk-costs-default-row' );
        costs_table.append( added_row );
        added_row.find( 'select.yith-wcbk-costs-range-type-select' ).trigger( 'change' );
    } );


    /** -------------------------------------------------------------------------------
     *                       P E R S O N   T Y P E S   T A B L E
     * --------------------------------------------------------------------------------
     */
    var person_types_table = $( '#yith-wcbk-booking-person-type-table' );

    /* ----  S o r t a b l e  ---- */
    person_types_table.find( 'tbody' ).sortable( {
                                                     items               : 'tr',
                                                     cursor              : 'move',
                                                     handle              : '.yith-wcbk-anchor',
                                                     axis                : 'y',
                                                     scrollSensitivity   : 40,
                                                     forcePlaceholderSize: true,
                                                     opacity             : 0.65,
                                                     helper              : function ( e, tr ) {
                                                         var originals = tr.children(),
                                                             helper    = tr.clone();
                                                         helper.children().each( function ( index ) {
                                                             // Set helper cell sizes to match the original sizes
                                                             $( this ).width( originals.eq( index ).width() );
                                                         } );
                                                         return helper;
                                                     }
                                                 } );

    $( 'input#_yith_booking_enable_person_types' ).on( 'change', function () {
        if ( $( this ).is( ':checked' ) ) {
            person_types_table.show();
        } else {
            person_types_table.hide();
        }
    } ).trigger( 'change' );

    /** -------------------------------------------------------------------------------
     *                  G o o g l e   M a p s   A u t o c o m p l e t e
     * --------------------------------------------------------------------------------
     */
    var maps_places_inputs = $( '.yith-wcbk-google-maps-places-autocomplete' );
    maps_places_inputs.each( function () {
        new google.maps.places.Autocomplete( this );
    } );
} );
