/* global yith_booking_form_params */
jQuery( document ).ready( function ( $ ) {
    "use strict";

    $.fn.yith_booking_form = function () {
        var $form                    = $( this ).closest( '.yith-wcbk-booking-form' ),
            product_id               = $form.data( 'product-id' ),
            booking_data             = $form.data( 'booking_data' ),
            duration_field           = $form.find( '.yith-wcbk-booking-duration' ),
            has_duration             = duration_field.length > 0,
            person_field             = $form.find( '.yith-wcbk-booking-persons' ),
            has_persons              = person_field.length > 0,
            person_types_fields      = $form.find( '.yith-wcbk-booking-person-types' ),
            has_person_types         = person_types_fields.length > 0,
            optional_services_fields = $form.find( 'input[type=checkbox].yith-wcbk-booking-service' ),
            has_optional_services    = optional_services_fields.length > 0,
            date_field               = $form.find( '.yith-wcbk-booking-start-date' ),
            end_date_field           = $form.find( '.yith-wcbk-booking-end-date' ),
            message                  = $form.find( '.yith-wcbk-booking-form-message' ),
            price                    = $form.closest( '.product' ).find( '.price' ).first(),
            add_to_cart              = $form.closest( 'form' ).find( 'button[type=submit]' ),
            block_params             = {
                message        : null,
                overlayCSS     : {
                    background: '#000',
                    opacity   : 0.6
                },
                ignoreIfBlocked: true
            };

        var booking_form_ajax_call = null;
        $form.on( 'change', 'input', function ( event ) {
            var duration      = duration_field.val(),
                persons       = person_field.val(),
                date          = date_field.val(),
                end_date      = end_date_field.val(),
                person_tot    = 0,
                error_message = '';

            if ( has_person_types ) {
                person_types_fields.each( function () {
                    person_tot += ($( this ).val() < 1) ? 0 : parseInt( $( this ).val() );
                } );
            } else {
                person_tot = persons < 1 ? 0 : parseInt( persons );
            }

            if ( !duration && has_duration ) {
                error_message += yith_booking_form_params.i18n_empty_duration + '<br />';
            }

            if ( !date || (end_date_field.length > 0 && !end_date) ) {
                error_message += yith_booking_form_params.i18n_empty_date + '<br />';
            }

            if ( person_tot < booking_data.min_persons ) {
                error_message += yith_booking_form_params.i18n_min_persons.replace( /%s/g, booking_data.min_persons ) + '<br />';
            }

            if ( booking_data.max_persons > 0 && person_tot > booking_data.max_persons ) {
                error_message += yith_booking_form_params.i18n_max_persons.replace( /%s/g, booking_data.max_persons ) + '<br />';
            }

            if ( error_message ) {
                message.html( '<p>' + error_message + '</p>' );
                add_to_cart.attr( 'disabled', true );

            } else {
                //booking_form.block( block_params );
                message.block( block_params );
                add_to_cart.block( block_params );
                price.block( block_params );

                var person_types      = [],
                    optional_services = [];
                if ( has_person_types ) {
                    person_types_fields.each( function () {
                        var person_type_id     = $( this ).data( 'person-type-id' ),
                            person_type_number = $( this ).val();

                        person_types.push( {
                                               id    : person_type_id,
                                               number: person_type_number
                                           } );
                    } );
                }

                if ( has_optional_services ) {
                    optional_services_fields.each( function () {
                        if ( $( this ).is( ':checked' ) ) {
                            var service_id = $( this ).data( 'service-id' );
                            optional_services.push( service_id );
                        }
                    } );
                }


                var post_data = {
                    product_id      : product_id,
                    duration        : duration,
                    from            : date,
                    to              : end_date,
                    persons         : persons,
                    person_types    : person_types,
                    booking_services: optional_services,
                    action          : 'yith_wcbk_get_booking_data',
                    context         : 'frontend'
                };

                if ( booking_form_ajax_call ) {
                    booking_form_ajax_call.abort();
                }

                booking_form_ajax_call = $.ajax( {
                                                     type   : "POST",
                                                     data   : post_data,
                                                     url    : yith_booking_form_params.ajaxurl,
                                                     success: function ( response ) {
                                                         try {
                                                             response = $.parseJSON( response );

                                                             if ( response.error ) {
                                                                 message.html( '<p class="error">' + response.error + '</p>' );
                                                             } else {
                                                                 if ( response.message )
                                                                     message.html( response.message );

                                                                 if ( response.price && response.price.length > 0 )
                                                                     price.html( response.price );

                                                                 if ( response.is_available ) {
                                                                     add_to_cart.attr( 'disabled', false );
                                                                 } else {
                                                                     add_to_cart.attr( 'disabled', true );
                                                                 }

                                                                 $form.trigger( 'yith_wcbk_form_update_response', response );
                                                             }
                                                         } catch ( err ) {
                                                             console.log( err.message );
                                                         }

                                                         //booking_form.unblock();
                                                         message.unblock();
                                                         add_to_cart.unblock();
                                                         price.unblock();
                                                     }
                                                 } );

            }
        } );

        // default start date
        if (date_field.val().length > 0){
            date_field.trigger('change');
        }
    };

    var init_form = function () {

            var datepickerFormat = 'yy-mm-dd';

            var datepicker   = $( '.yith-wcbk-date-picker' ),
                booking_form = $( '.yith-wcbk-booking-form' );

            datepicker.each( function () {
                var minDate           = $( this ).data( 'min-date' ),
                    maxDate           = $( this ).data( 'max-date' ),
                    notAvailableDates = $( this ).data( 'not-available-dates' ),
                    to                = $( $( this ).data( 'related-to' ) ),
                    from              = $( $( this ).data( 'related-from' ) );
                $( this ).datepicker( {
                                          dateFormat   : datepickerFormat,
                                          minDate      : minDate,
                                          maxDate      : maxDate,
                                          showAnim     : false,
                                          beforeShow   : function () {
                                              $( '#ui-datepicker-div' ).addClass( 'yith-wcbk-datepicker' );
                                          },
                                          beforeShowDay: function ( date ) {
                                              if ( typeof notAvailableDates == 'undefined' || notAvailableDates == null || !notAvailableDates )
                                                  return [ true ];

                                              var string = $.datepicker.formatDate( 'yy-mm-dd', date );
                                              return [ notAvailableDates.indexOf( string ) == -1 ];
                                          },
                                          onClose      : function ( selectedDate ) {
                                              $( '#ui-datepicker-div' ).removeClass( 'yith-wcbk-datepicker' );
                                              if ( selectedDate ) {
                                                  if ( to.length > 0 )
                                                      to.datepicker( "option", "minDate", selectedDate );
                                                  else if ( from.length > 0 )
                                                      from.datepicker( "option", "maxDate", selectedDate );
                                              }
                                          }
                                      } );
            } );

            /** =====================================================
             *                 M O N T H   P I C K E R
             *  =====================================================
             */

            var month_picker_wrapper = $( '.yith-wcbk-month-picker-wrapper' );

            month_picker_wrapper.on( 'click', '.month.enabled', function ( e ) {
                    var month_picker       = $( this ).closest( '.yith-wcbk-month-picker-wrapper' ),
                        months             = month_picker.find( '.selected' ),
                        month              = $( e.target ),
                        selected_value     = month.data( 'value' ),
                        month_picker_value = month_picker.find( '.yith-wcbk-month-picker-value' );

                    if ( !month.is( '.selected' ) ) {
                        months.removeClass( 'selected' );
                        month.addClass( 'selected' );
                        month_picker_value.val( selected_value );
                        month_picker_value.trigger( 'change' );
                    }
                } )

                .on( 'click', '.prev, .next', function ( e ) {
                    var month_picker = $( this ).closest( '.yith-wcbk-month-picker-wrapper' ),
                        target       = $( e.target ).closest( 'div' ),
                        current_year = parseInt( month_picker.data( 'current-year' ) ),
                        year_to_show = target.is( '.prev' ) ? ( current_year - 1) : ( current_year + 1),
                        to_show      = month_picker.find( '.year-' + year_to_show );

                    if ( target.is( '.enabled' ) && to_show.length > 0 ) {
                        month_picker.find( '.year' ).hide();
                        to_show.show();
                        month_picker.data( 'current-year', year_to_show );
                    }
                } );


            booking_form.each( function () {
                $( this ).yith_booking_form();
            } );


            booking_form.find( '.help_tip' ).tipTip( {
                                                         'attribute': 'data-tip',
                                                         'fadeIn'   : 50,
                                                         'fadeOut'  : 50,
                                                         'delay'    : 200
                                                     } );


            $( document ).trigger( 'yith-wcbk-booking-form-loaded' );
        }
        ;

    $( document ).on( 'yith-wcbk-init-booking-form', function () {
        init_form();
    } ).trigger( 'yith-wcbk-init-booking-form' );
    
    // compatibility with YITH WooCommerce Quick View
    $( document ).on( 'qv_loader_stop', function () {
        $( document ).trigger( 'yith-wcbk-init-booking-form' );
    } );

} );