<?php
/**
 * Booking Calendar class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Booking_Calendar' ) ) {

    class YITH_WCBK_Booking_Calendar {
        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Booking_Calendar
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Booking_Calendar
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @access public
         * @since  1.0.0
         */
        protected function __construct() {
            add_action( 'admin_menu', array( $this, 'add_submenu' ) );
        }

        /**
         * add Calendar Submenu to Booking Admin Menu
         */
        public function add_submenu() {
            add_submenu_page( 'edit.php?post_type=' . YITH_WCBK_Post_Types::$booking,               //parent_slug
                __( 'Calendar', 'yith-booking-for-woocommerce' ),                         //page_title
                __( 'Calendar', 'yith-booking-for-woocommerce' ),                         //menu_title
                'edit_' . YITH_WCBK_Post_Types::$booking . 's',                       // capability
                'yith-wcbk-booking-calendar',                                         // menu_slug
                array( $this, 'render_calendar_page' )                                // callback function
            );
        }

        /**
         * Render Calendar page in base of requests
         */
        public function render_calendar_page() {
            echo '<div class="wrap">';
            echo '<h1>' . __( 'Calendar', 'yith-booking-for-woocommerce' ) . '</h1>';

            $view      = isset( $_REQUEST[ 'view' ] ) ? $_REQUEST[ 'view' ] : 'month';
            $view_file = YITH_WCBK_DIR . 'includes/booking/admin/html/calendar/html-booking-calendar-' . $view . '.php';
            $args      = array();

            switch ( $view ) {
                case 'month':
                    $month = isset( $_REQUEST[ 'month' ] ) ? absint( $_REQUEST[ 'month' ] ) : date( 'n' );
                    $year  = isset( $_REQUEST[ 'year' ] ) ? absint( $_REQUEST[ 'year' ] ) : date( 'Y' );

                    $start_of_week              = absint( get_option( 'start_of_week', 1 ) );
                    $first_day_of_current_month = date( 'N', strtotime( "$year-$month-01" ) );

                    $diff = $start_of_week - $first_day_of_current_month;

                    $start_timestamp = strtotime( $diff . ' days midnight', strtotime( "$year-$month-01" ) );
                    $end_timestamp   = strtotime( '+34 days midnight', $start_timestamp );

                    $last_day_of_month = strtotime( '+1 month -1 day', strtotime( "$year-$month-01" ) );
                    if ( $end_timestamp < $last_day_of_month ) {
                        $end_timestamp = strtotime( '+7 days', $end_timestamp );
                    }

                    $bookings = YITH_WCBK_Booking_Helper()->get_bookings_in_time_range( $start_timestamp, $end_timestamp );

                    $args = array(
                        'month'           => $month,
                        'year'            => $year,
                        'start_timestamp' => $start_timestamp,
                        'end_timestamp'   => $end_timestamp,
                        'bookings'        => $bookings
                    );


                    break;
            }

            extract( $args );
            if ( file_exists( $view_file ) ) {
                include( $view_file );
            }

            echo "</div>";
        }

        /**
         *
         */
        public function print_action_bar( $args ) {
            extract( $args );
            $view_file = YITH_WCBK_DIR . 'includes/booking/admin/html/calendar/html-booking-calendar-action-bar.php';

            if ( file_exists( $view_file ) ) {
                include( $view_file );
            }
        }
    }
}

return YITH_WCBK_Booking_Calendar::get_instance();