<?php
/**
 * Frontend class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */

if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Frontend' ) ) {
    /**
     * Frontend class.
     * The class manage all the Frontend behaviors.
     *
     * @since    1.0.0
     * @author   Leanza Francesco <leanzafrancesco@gmail.com>
     */
    class YITH_WCBK_Frontend {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Frontend
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * @var YITH_WCBK_Cart
         */
        public $cart;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Frontend
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @access public
         * @since  1.0.0
         */
        public function __construct() {
            // Manage Cart for bookings
            $this->cart = YITH_WCBK_Cart::get_instance();

            // Handler for frontend actions (request confirmation, pay booking, cancel booking)
            YITH_WCBK_Frontend_Action_Handler::init();

            // print add-to-cart template for Booking product
            $booking_form_position = get_option( 'yith-wcbk-booking-form-position', 'default' );
            switch ( $booking_form_position ) {
                case 'default':
                    add_action( 'woocommerce_booking_add_to_cart', array( $this, 'print_add_to_cart_template' ) );
                    break;
                case 'before_summary':
                    add_action( 'woocommerce_before_single_product_summary', array( $this, 'print_add_to_cart_template' ) );
                    break;
                case 'after_title':
                    add_action( 'woocommerce_single_product_summary', array( $this, 'print_add_to_cart_template' ), 7 );
                    break;
                case 'before_description':
                    add_action( 'woocommerce_single_product_summary', array( $this, 'print_add_to_cart_template' ), 15 );
                    break;
                case 'after_description':
                    add_action( 'woocommerce_single_product_summary', array( $this, 'print_add_to_cart_template' ), 25 );
                    break;
                case 'after_summary':
                    add_action( 'woocommerce_after_single_product_summary', array( $this, 'print_add_to_cart_template' ) );

                    break;
            }

            add_action( 'yith_wcbk_booking_add_to_cart_form', array( $this, 'print_add_to_cart_template' ) );

            // Search form frontend management
            YITH_WCBK_Search_Form_Frontend::get_instance();

            // Load Frontend Styles and scripts
            YITH_WCBK_Frontend_Assets::get_instance();
        }

        /**
         * Print add-to-cart template for Booking product
         *
         * @return void
         */
        public function print_add_to_cart_template() {
            global $product;
            if ( YITH_WCBK_Product_Helper::is_booking( $product ) ) {
                wc_get_template( 'single-product/add-to-cart/booking.php', array(), '', YITH_WCBK_TEMPLATE_PATH );
            }
        }
    }
}
/**
 * Unique access to instance of YITH_WCBK_Frontend class
 *
 * @return \YITH_WCBK_Frontend
 * @since 1.0.0
 */
function YITH_WCBK_Frontend() {
    return YITH_WCBK_Frontend::get_instance();
}
