<?php
/**
 * Language class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Language' ) ) {
    /**
     * YITH_WCBK_Language
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Language {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Language
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * @var array
         */
        private $_labels = array();

        /**
         * @var array|mixed|void
         */
        private $_default_labels = array();

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Language
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         */
        private function __construct() {
            $this->_default_labels = apply_filters( 'yith_wcbk_language_default_labels', array(
                'add-to-cart'          => _x( 'Add to cart', 'Text of add-to-cart-button for booking products', 'yith-booking-for-woocommerce' ),
                'read-more'            => _x( 'Read more', 'Text of add-to-cart-button for booking products', 'yith-booking-for-woocommerce' ),
                'request-confirmation' => _x( 'Request Confirmation', 'Text of add-to-cart-button for booking products', 'yith-booking-for-woocommerce' ),
                'bookable'             => __( 'Bookable', 'yith-booking-for-woocommerce' ),
                'not-bookable'         => __( 'Non-bookable', 'yith-booking-for-woocommerce' ),
                'check-in'             => __( 'Check-in', 'yith-booking-for-woocommerce' ),
                'check-out'            => __( 'Check-out', 'yith-booking-for-woocommerce' ),
                'start-date'           => __( 'Start date', 'yith-booking-for-woocommerce' ),
                'end-date'             => __( 'End date', 'yith-booking-for-woocommerce' ),
            ) );
        }

        /**
         * get a label
         *
         * @param $key
         *
         * @return mixed
         */
        public function get_label( $key ) {
            if ( isset( $this->_labels[ $key ] ) )
                return $this->_labels[ $key ];

            $label = get_option( 'yith-wcbk-label-' . sanitize_text_field( $key ), '' );

            if ( !$label ) {
                $label = $this->get_default_label( $key );
            }

            $this->_labels[ $key ] = apply_filters( 'yith_wcbk_language_get_label', $label, $key );

            return $this->_labels[ $key ];
        }

        /**
         *
         * get the default label
         *
         * @param $key
         *
         * @return mixed|string
         */
        public function get_default_label( $key ) {
            return isset( $this->_default_labels[ $key ] ) ? $this->_default_labels[ $key ] : '';
        }

        /**
         * get the default label array
         *
         * @return array|mixed|void
         */
        public function get_default_labels() {
            return $this->_default_labels;
        }
    }
}