<?php
/**
 * Person Type Helper class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Person_Type_Helper' ) ) {
    /**
     * YITH Booking for WooCommerce Premium Person Type Helper
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Person_Type_Helper {
        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Person_Type_Helper
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * the booking post type name
         *
         * @var string
         * @since 1.0.0
         */
        public $post_type_name;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Person_Type_Helper
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         */
        public function __construct() {
            $this->post_type_name = YITH_WCBK_Post_Types::$person_type;
        }

        /**
         * Get all person types by arguments
         *
         *
         * @param array $args argument for get_posts
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         * @return WP_Post[]|bool
         */
        public function get_person_types( $args = array() ) {
            $do_actions = !isset( $args[ 'suppress_filters' ] ) || $args[ 'suppress_filters' ] === true;
            if ( $do_actions )
                do_action( 'yith_wcbk_before_get_person_types', $args );

            $default_args = array(
                'post_type'        => $this->post_type_name,
                'post_status'      => 'publish',
                'posts_per_page'   => -1,
                'suppress_filters' => false,
            );

            $args  = wp_parse_args( $args, $default_args );
            $posts = get_posts( $args );

            if ( $do_actions )
                do_action( 'yith_wcbk_after_get_person_types', $args );

            return $posts;
        }

        /**
         * Get all person type ids by arguments
         *
         *
         * @param array $args argument for get_posts
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         * @return int[]|bool
         */
        public function get_person_type_ids( $args = array() ) {
            $default_args = array(
                'fields' => 'ids',
            );

            $args = wp_parse_args( $args, $default_args );

            return $this->get_person_types( $args );
        }


        /**
         * Get all person types in array id => name
         *
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         * @return array
         */
        public function get_person_types_array() {
            $ids          = $this->get_person_type_ids();
            $person_types = array();

            if ( !!$ids && is_array( $ids ) ) {
                foreach ( $ids as $id ) {
                    $person_types[ $id ] = get_the_title( $id );
                }
            }

            return $person_types;
        }

        /**
         * @param $person_type_id
         *
         * @return string
         */
        public function get_person_type_title( $person_type_id ) {
            return apply_filters( 'yith_wcbk_get_person_type_title', get_the_title( $person_type_id ), $person_type_id );
        }

    }
}