<?php
/**
 * Service Helper class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Service_Helper' ) ) {
    /**
     * YITH Booking for WooCommerce Premium Service Helper
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Service_Helper {
        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Service_Helper
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * the service taxonomy name
         *
         * @var string
         * @since 1.0.0
         */
        public $taxonomy_name;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Service_Helper
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         */
        public function __construct() {
            $this->taxonomy_name = YITH_WCBK_Post_Types::$service_tax;
        }

        /**
         * Get all services by arguments
         *
         *
         * @param array  $args argument for get_terms
         * @param string $return the object type returned
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         * @return WP_Post[]|YITH_WCBK_Service[]|bool
         */
        public function get_services( $args = array(), $return = 'services' ) {
            $default_args = array(
                'hide_empty' => false,
            );

            $args = wp_parse_args( $args, $default_args );

            $is_id_name_assoc = isset( $args[ 'fields' ] ) && $args[ 'fields' ] === 'id=>name';
            if ( $is_id_name_assoc ) {
                $return = 'terms';
            }

            $args[ 'taxonomy' ] = $this->taxonomy_name;
            $services = YITH_WCBK()->wp->get_terms( $args );

            switch ( $return ) {
                case 'terms':
                    return $services;
                    break;
                case 'services':
                default:
                    return $this->parse_services_from_terms( $services );
            }
        }

        /**
         * parse terms and return array of YITH_WCBK_Service
         *
         * @param WP_Term|WP_Term[] $service_terms the terms
         *
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         * @return YITH_WCBK_Service[]|bool
         */
        public function parse_services_from_terms( $service_terms ) {
            if ( !empty( $service_terms ) ) {
                $service_terms = (array) $service_terms;
                $services      = array();
                foreach ( $service_terms as $term ) {
                    $service    = yith_get_booking_service( $term->term_id );
                    $services[] = $service;
                }

                return $services;
            }

            return false;
        }
    }
}