<?php
/**
 * Shortcodes class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */

if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Shortcodes' ) ) {
    /**
     * Shortcodes class.
     * Registers and manages shortcodes
     *
     * @since    1.0.0
     * @author   Leanza Francesco <leanzafrancesco@gmail.com>
     */
    class YITH_WCBK_Shortcodes {

        public static function init() {
            $shortcodes = array(
                'booking_form'        => __CLASS__ . '::booking_form', // print booking form
                'booking_search_form' => __CLASS__ . '::booking_search_form', // print booking form
                'booking_map'         => __CLASS__ . '::booking_map', // print booking form
            );

            foreach ( $shortcodes as $shortcode => $function ) {
                add_shortcode( $shortcode, $function );
            }
        }

        public static function booking_form( $atts ) {
            global $product;
            ob_start();
            $booking_id = isset( $atts[ 'id' ] ) ? $atts[ 'id' ] : 0;

            if ( !$booking_id && $product && $product->get_id() ) {
                $booking_id = $product->get_id();
            }

            if ( $booking_id ) {
                $booking_product = wc_get_product( $booking_id );
                if ( $booking_product && $booking_product->is_type( YITH_WCBK_Product_Helper::$prod_type ) ) {
                    global $product, $post;
                    $old_product = $product;
                    $old_post    = $post;
                    $post        = get_post( $booking_product->get_id() );
                    $product     = $booking_product;
                    wc_get_template( 'shortcodes/booking-form.php', array(), '', YITH_WCBK_TEMPLATE_PATH );
                    $product = $old_product;
                    $post    = $old_post;
                }
            }

            return ob_get_clean();
        }

        public static function booking_search_form( $atts ) {
            ob_start();
            $form_id = isset( $atts[ 'id' ] ) ? $atts[ 'id' ] : 0;
            if ( $form_id ) {
                $form = new YITH_WCBK_Search_Form( $form_id );
                $form->output();
            }

            return ob_get_clean();
        }

        public static function booking_map( $atts ) {
            $product_id = isset( $atts[ 'id' ] ) ? absint( $atts[ 'id' ] ) : false;
            ob_start();
            if ( !$product_id ) {
                global $post;
                $product_id = !!$post ? $post->ID : false;
            }

            $product = !!$product_id ? wc_get_product( $product_id ) : false;
            /**
             * @var WC_Product_Booking $product
             */
            if ( $product && $product->is_type( YITH_WCBK_Product_Helper::$prod_type ) && $coordinates = $product->get_location_coordinates() ) {
                $width  = isset( $atts[ 'width' ] ) ? $atts[ 'width' ] : '100%';
                $height = isset( $atts[ 'height' ] ) ? $atts[ 'height' ] : '500px';
                $zoom   = isset( $atts[ 'zoom' ] ) ? absint( $atts[ 'zoom' ] ) : 9;
                $type   = isset( $atts[ 'type' ] ) ? $atts[ 'type' ] : 'ROADMAP';

                $width  = ( !is_numeric( $width ) ) ? $width : $width . 'px';
                $height = ( !is_numeric( $height ) ) ? $height : $height . 'px';

                wc_get_template( 'shortcodes/booking-map.php', compact( 'coordinates', 'product', 'width', 'height', 'zoom', 'type' ), '', YITH_WCBK_TEMPLATE_PATH );

            }

            return ob_get_clean();

        }

    }
}