<?php
/**
 * Main class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK' ) ) {
    /**
     * YITH Booking for WooCommerce Premium
     *
     * @since 1.0.0
     */
    class YITH_WCBK {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Plugin version
         *
         * @var string
         * @since 1.0.0
         */
        public $version = YITH_WCBK_VERSION;

        /**
         * @var \YITH_WCBK_Admin
         * @since 1.0.0
         */
        public $admin;

        /**
         * @var \YITH_WCBK_Frontend
         * @since 1.0.0
         */
        public $frontend;

        /**
         * @var \YITH_WCBK_Order
         * @since 1.0.0
         */
        public $order_manager;

        /**
         * @var \YITH_WCBK_Person_Type_Helper
         * @since 1.0.0
         */
        public $person_type_helper;

        /**
         * @var \YITH_WCBK_Service_Helper
         * @since 1.0.0
         */
        public $service_helper;

        /**
         * @var YITH_WCBK_Booking_Helper
         */
        public $booking_helper;

        /**
         * @var YITH_WCBK_Search_Form_Helper
         */
        public $search_form_helper;

        /**
         * @var YITH_WCBK_Notes
         */
        public $notes;

        /**
         * @var YITH_WCBK_Notifier
         */
        public $notifier;

        /**
         * @var YITH_WCBK_Settings
         */
        public $settings;

        /**
         * @var YITH_WCBK_Maps
         */
        public $maps;

        /**
         * @var YITH_WCBK_Exporter
         */
        public $exporter;

        /**
         * @var YITH_WCBK_Enpoints
         */
        public $endpoints;

        /**
         * @var YITH_WCBK_Integrations
         */
        public $integrations;

        /**
         * @var YITH_WCBK_Language
         */
        public $language;

        /**
         * @var YITH_WCBK_WP_Compatibility
         */
        public $wp;

        /**
         * Plugin object
         *
         * @var string
         * @since 1.0.0
         */
        public $obj = null;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @return mixed| YITH_WCBK_Admin | YITH_WCBK_Frontend
         * @since 1.0.0
         */
        private function __construct() {
            // Load Plugin Framework
            add_action( 'plugins_loaded', array( $this, 'plugin_fw_loader' ), 15 );

            // init Post Types
            YITH_WCBK_Post_Types::init();

            // init Shortcodes
            YITH_WCBK_Shortcodes::init();

            // Class admin
            if ( is_admin() && !defined( 'DOING_AJAX' ) || ( defined( 'DOING_AJAX' ) && DOING_AJAX && ( !isset( $_REQUEST[ 'context' ] ) || ( isset( $_REQUEST[ 'context' ] ) && $_REQUEST[ 'context' ] !== 'frontend' ) ) ) ) {
                $this->admin = YITH_WCBK_Admin();
            } else {
                $this->frontend = YITH_WCBK_Frontend();
            }

            YITH_WCBK_AJAX::get_instance();

            YITH_WCBK_Product_Form_Helper::get_instance();

            $this->person_type_helper = YITH_WCBK_Person_Type_Helper::get_instance();
            $this->service_helper     = YITH_WCBK_Service_Helper::get_instance();
            $this->booking_helper     = YITH_WCBK_Booking_Helper::get_instance();
            $this->search_form_helper = YITH_WCBK_Search_Form_Helper::get_instance();

            $this->order_manager = YITH_WCBK_Order::get_instance();
            $this->notes         = YITH_WCBK_Notes::get_instance();
            $this->notifier      = YITH_WCBK_Notifier::get_instance();
            $this->settings      = YITH_WCBK_Settings::get_instance();

            $this->maps      = YITH_WCBK_Maps::get_instance();
            $this->exporter  = YITH_WCBK_Exporter::get_instance();
            $this->endpoints = YITH_WCBK_Enpoints::get_instance();
            $this->language  = YITH_WCBK_Language::get_instance();

            $this->integrations = YITH_WCBK_Integrations::get_instance();

            $this->wp = YITH_WCBK_WP_Compatibility::get_instance();

            add_action( 'widgets_init', array( $this, 'register_widgets' ) );

        }


        /**
         * Load Plugin Framework
         *
         * @since  1.0
         * @access public
         * @return void
         * @author Andrea Grillo <andrea.grillo@yithemes.com>
         */
        public function plugin_fw_loader() {
            if ( !defined( 'YIT_CORE_PLUGIN' ) ) {
                global $plugin_fw_data;
                if ( !empty( $plugin_fw_data ) ) {
                    $plugin_fw_file = array_shift( $plugin_fw_data );
                    require_once( $plugin_fw_file );
                }
            }
        }


        /**
         * register Widget for Messages
         *
         * @access public
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         */
        public function register_widgets() {
            register_widget( 'YITH_WCBK_Search_Form_Widget' );
        }

    }
}

/**
 * Unique access to instance of YITH_WCBK class
 *
 * @return \YITH_WCBK
 * @since 1.0.0
 */
function YITH_WCBK() {
    return YITH_WCBK::get_instance();
}

