<?php
/**
 * Exporter class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Exporter' ) ) {
    /**
     * YITH Booking for WooCommerce Premium Exporter
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Exporter {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Exporter
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Exporter
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @return YITH_WCBK_Exporter
         * @since 1.0.0
         */
        protected function __construct() {

        }

        /**
         * transform an array to CSV file
         *
         * @param        $array
         * @param string $filename
         * @param string $delimiter
         */
        public function array_to_csv_download( $array, $filename = 'export.csv', $delimiter = ',' ) {
            header( "X-Robots-Tag: noindex, nofollow", true );
            header( "Content-Type: application/csv" );
            header( "Content-Disposition: attachment; filename=\"" . $filename . "\";" );
            $f = fopen( 'php://output', 'w' );

            foreach ( $array as $line ) {
                fputcsv( $f, $line, $delimiter );
            }
            exit;
        }

        /**
         * Generate the template
         *
         * @param int  $booking_id
         * @param bool $is_admin
         */
        public function generate_pdf( $booking_id, $is_admin = true ) {
            $filename = 'booking_' . $booking_id . '.pdf';
            $booking  = yith_get_booking( $booking_id );

            ob_start();
            wc_get_template( 'booking/pdf/booking.php', array( 'booking' => $booking, 'booking_id' => $booking_id, 'is_admin' => $is_admin ), '', YITH_WCBK_TEMPLATE_PATH );
            $html = ob_get_clean();
            //echo $html;exit;

            require_once( YITH_WCBK_DOMPDF_DIR . "dompdf_config.inc.php" );
            $pdf = new DOMPDF();
            $pdf->load_html( $html );
            $pdf->render();
            //$pdf = $dompdf->output();

            $pdf_options = array(
                'Attachment' => 0, // 0 -> open | 1 -> download
            );
            $pdf->stream( $filename, $pdf_options );
            die();
        }

        /**
         * Download bookings in a file
         *
         * @param array  $post_ids array of booking ids
         * @param string $format format of download file. Allowed: csv
         */
        public function download_bookings( $post_ids, $format = 'csv' ) {
            $post_ids = !!$post_ids ? (array) $post_ids : array();

            $booking_fields = array(
                'booking_id',
                'product_id',
                'product_name',
                'date',
                'status',
                'order_id',
                'user_id',
                'username',
                'duration',
                'from',
                'to',
                'services',
                'persons',
                'person_types',
            );

            $csv_array = array( $booking_fields );

            foreach ( $post_ids as $post_id ) {
                $booking = yith_get_booking( $post_id );
                if ( $booking->is_valid() ) {
                    $current_booking = array();
                    foreach ( $booking_fields as $booking_field ) {
                        $val = '';
                        switch ( $booking_field ) {
                            case 'booking_id':
                                $val = $booking->id;
                                break;
                            case 'product_id':
                                $val = !empty( $booking->product_id ) ? $booking->product_id : '';
                                break;
                            case 'product_name':
                                $val = get_the_title( $booking->product_id );
                                break;
                            case 'date':
                                $val = date_i18n( wc_date_format() . ' ' . wc_time_format(), strtotime( $booking->post->post_date ) );
                                break;
                            case 'status':
                                $val = $booking->get_status_text();
                                break;
                            case 'order_id':
                                $val = !empty( $booking->order_id ) ? $booking->order_id : '';
                                break;
                            case 'user_id':
                                $val = !empty( $booking->user_id ) ? $booking->user_id : '';
                                break;
                            case 'username':
                                $val = '';
                                if ( !empty( $booking->user_id ) ) {
                                    $user_id = absint( $booking->user_id );
                                    $user    = get_user_by( 'id', $user_id );
                                    $val     = $user->nickname;
                                }
                                break;
                            case 'duration':
                                $val = !empty( $booking->duration ) ? $booking->duration : '';
                                break;
                            case 'from':
                                $val = $booking->get_formatted_date( 'from' );
                                break;
                            case 'to':
                                $val = $booking->get_formatted_date( 'to' );
                                break;
                            case 'services':
                                $services = $booking->get_service_names();

                                $val = !!$services ? implode( ', ', $services ) : '';
                                break;

                            case 'persons':
                                $val = !empty( $booking->persons ) ? $booking->persons : '';
                                break;

                            case 'person_types':
                                $val = '';
                                if ( $booking->has_person_types() ) {
                                    foreach ( $booking->person_types as $person_type ) {
                                        $id     = isset( $person_type[ 'id' ] ) ? $person_type[ 'id' ] : false;
                                        $title  = !!( $person_type[ 'title' ] ) ? $person_type[ 'title' ] : false;
                                        $number = isset( $person_type[ 'number' ] ) ? $person_type[ 'number' ] : false;

                                        if ( $id === false || $title === false || !$number )
                                            continue;

                                        $person_type_title = get_the_title( $id );
                                        $title             = !!$person_type_title ? $person_type_title : $title;
                                        $val .= "$title($number) ";
                                    }
                                }
                                break;

                        }

                        $hook              = 'yith_wcbk_csv_field_' . $booking_field;
                        $current_booking[] = apply_filters( $hook, $val, $booking );
                    }

                    $csv_array[] = $current_booking;
                }

            }

            $delimiter = ',';
            $filename  = 'yith-bookings-' . date( 'Y-m-d' ) . '.csv';

            $this->array_to_csv_download( $csv_array, $filename, $delimiter );
        }
    }
}