<?php
/**
 * Template options in WC Product Panel
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

?>

    <div class="options_group">

        <?php

        $days_array = yith_wcbk_get_days_array();

        $range_time_array = array(
            'month' => __( 'Month(s)', 'yith-booking-for-woocommerce' ),
            'day'   => __( 'Day(s)', 'yith-booking-for-woocommerce' ),
            //'hour'   => __( 'Hour(s)', 'yith-booking-for-woocommerce' ),
            //'minute' => __( 'Minute(s)', 'yith-booking-for-woocommerce' )
        );

        $range_time_array_with_year = array(
            'year'  => __( 'Year(s)', 'yith-booking-for-woocommerce' ),
            'month' => __( 'Month(s)', 'yith-booking-for-woocommerce' ),
            'day'   => __( 'Day(s)', 'yith-booking-for-woocommerce' ),
            //'hour'   => __( 'Hour(s)', 'yith-booking-for-woocommerce' ),
            //'minute' => __( 'Minute(s)', 'yith-booking-for-woocommerce' )
        );

        $max_booking_per_block = get_post_meta( $post_id, '_yith_booking_max_per_block', true );
        // set default to 1
        $max_booking_per_block = ( $max_booking_per_block == '' ) ? 1 : $max_booking_per_block;


        /* -------- available_allowed_start_days_fields START -------- */
        $available_allowed_start_days_fields = array(
            array(
                'type'  => 'label',
                'value' => __( 'Allowed start days', 'yith-booking-for-woocommerce' ),
            ),
            array(
                'type'  => 'html',
                'value' => '<span class="yith-wcbk-weekdays-checkboxes">',
            )
        );
        foreach ( $days_array as $day_number => $day_name ) {
            $day_name                              = substr( $day_name, 0, 3 );
            $available_allowed_start_days_fields[] = array(
                'type'            => 'onoff',
                'container_class' => 'yith-wcbk-day-onoff',
                'enabled_class'   => 'yith-wcbk-day-onoff-enabled',
                'disabled_class'  => 'yith-wcbk-day-onoff-disabled',
                'enabled_text'    => $day_name,
                'disabled_text'   => $day_name,
//                'name'            => '_yith_booking_allowed_start_days[' . $day_number . '][]',
//                'value'           => 'yes',
                'name'            => '_yith_booking_allowed_start_days[]',
                'value'           => $day_number,
            );
        }
        $available_allowed_start_days_fields[] = array(
            'type'  => 'html',
            'value' => '</span>',
        );
        $available_allowed_start_days_fields[] = array(
            'type'  => 'help-tip',
            'value' => __( 'Select allowed days for the starting date.', 'yith-booking-for-woocommerce' )
        );
        /* -------- available_allowed_start_days_fields END -------- */


        $available_tab_fields = array(
            array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_available_max_per_block_field',
                'fields' => array(
                    array(
                        'type'              => 'number',
                        'title'             => __( 'Max bookings per unit', 'yith-booking-for-woocommerce' ),
                        'value'             => $max_booking_per_block,
                        'id'                => '_yith_booking_max_per_block',
                        'custom_attributes' => 'step="1" min="0"',
                        'help_tip'          => __( 'Select the maximum number of bookings allowed for each unit. Set zero for unlimited.',
                                                   'yith-booking-for-woocommerce' ),
                    ),
                ),
            ),
            array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_available_allow_after_field yith_booking_multi_fields',
                'fields' => array(
                    array(
                        'type'              => 'number',
                        'title'             => __( 'Allow booking no sooner than', 'yith-booking-for-woocommerce' ),
                        'value'             => get_post_meta( $post_id, '_yith_booking_allow_after', true ),
                        'id'                => '_yith_booking_allow_after',
                        'custom_attributes' => 'step="1" min="0"',
                    ),
                    array(
                        'type'    => 'select',
                        'value'   => get_post_meta( $post_id, '_yith_booking_allow_after_unit', true ),
                        'id'      => '_yith_booking_allow_after_unit',
                        'class'   => 'select',
                        'options' => $range_time_array,
                    ),
                ),
            ),
            array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_available_allow_until_field yith_booking_multi_fields',
                'fields' => array(
                    array(
                        'type'              => 'number',
                        'title'             => __( 'Allow booking no later than', 'yith-booking-for-woocommerce' ),
                        'value'             => get_post_meta( $post_id, '_yith_booking_allow_until', true ),
                        'id'                => '_yith_booking_allow_until',
                        'custom_attributes' => 'step="1" min="1"',
                    ),
                    array(
                        'type'    => 'select',
                        'value'   => get_post_meta( $post_id, '_yith_booking_allow_until_unit', true ),
                        'id'      => '_yith_booking_allow_until_unit',
                        'class'   => 'select',
                        'options' => $range_time_array_with_year,
                    ),
                ),
            ),
            array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_available_checkin_field',
                'fields' => array(
                    array(
                        'type'     => 'text',
                        'title'    => __( 'Check-in', 'yith-booking-for-woocommerce' ),
                        'value'    => get_post_meta( $post_id, '_yith_booking_checkin', true ),
                        'id'       => '_yith_booking_checkin',
                        'help_tip' => __( 'Insert check-in time here', 'yith-booking-for-woocommerce' ),
                    ),
                ),
            ),
            array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_available_checkout_field',
                'fields' => array(
                    array(
                        'type'     => 'text',
                        'title'    => __( 'Check-out', 'yith-booking-for-woocommerce' ),
                        'value'    => get_post_meta( $post_id, '_yith_booking_checkout', true ),
                        'id'       => '_yith_booking_checkout',
                        'help_tip' => __( 'Insert check-out time here', 'yith-booking-for-woocommerce' ),
                    ),
                ),
            ),
            array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_default_start_date',
                'fields' => array(
                    array(
                        'type'     => 'select',
                        'class' => 'select short',
                        'title'    => __( 'Default start date', 'yith-booking-for-woocommerce' ),
                        'value'    => get_post_meta( $post_id, '_yith_booking_default_start_date', true ),
                        'id'       => '_yith_booking_default_start_date',
                        'options' => array(
                            ''          => __( 'None', 'yith-booking-for-woocommerce' ),
                            'today'     => __( 'Today', 'yith-booking-for-woocommerce' ),
                            'tomorrow'  => __( 'Tomorrow', 'yith-booking-for-woocommerce' ),
                            'custom'    => __( 'Custom Date', 'yith-booking-for-woocommerce' ),
                        ),
                        'help_tip' => __( 'Insert the default start date here. Please, note: <b>Today</b> and <b>Tomorrow</b> are dynamic dates, based on when the user accesses the page.', 'yith-booking-for-woocommerce' ),
                    ),
                ),
            ),
            array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_default_start_date_custom yith-wcbk-show-conditional',
                'data'  => array(
                    'field-id'  => '_yith_booking_default_start_date',
                    'value'     => 'custom',
                ),
                'fields' => array(
                    array(
                        'type'  => 'text',
                        'class' => 'yith-wcbk-date-input-field yith-wcbk-admin-date-picker',
                        'title' => __( 'Custom Default Start Date', 'yith-booking-for-woocommerce' ),
                        'name'  => '_yith_booking_default_start_date_custom',
                        'value' => get_post_meta( $post_id, '_yith_booking_default_start_date_custom', true ),
                    )
                ),
            ),
            /*array(
                'type'   => 'section',
                'class'  => 'form-field _yith_booking_available_allowed_start_days_field',
                'fields' => $available_allowed_start_days_fields,
            ),*/
        );

        YITH_WCBK_Printer()->print_fields( $available_tab_fields );
        ?>
    </div>

<?php
include( YITH_WCBK_TEMPLATE_PATH . '/admin/product-tabs/utility/availability-table.php' );
?>