<?php
/**
 * Booking form dates
 *
 * @author        Leanza Francesco <leanzafrancesco@gmail.com>
 *
 * @var WC_Product_Booking $product
 */

if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
$unit = $product->get_duration_unit();

?>
<div class="yith-wcbk-form-section-dates-wrapper">
    <?php
    $fields_to_print = array();

    if ( 'month' === $unit || ( 'day' === $unit && !$product->has_calendar_picker_enabled() ) ) {
        $duration_label_html = '';
        $duration            = $product->get_booking_prop( 'duration' );
        $is_fixed_blocks     = $product->is_type_fixed_blocks();

        if ( $is_fixed_blocks ) {
            switch ( $product->get_duration_unit() ) {
                case 'month' :
                    $duration_label_html = sprintf( _n( '%s month', '%s months', $duration, 'yith-booking-for-woocommerce' ), $duration );
                    break;
                case 'week' :
                    $duration_label_html = sprintf( _n( '%s week', '%s weeks', $duration, 'yith-booking-for-woocommerce' ), $duration );
                    break;
                case 'day' :
                    $duration_label_html = sprintf( _n( '%s day', '%s days', $duration, 'yith-booking-for-woocommerce' ), $duration );
                    break;
                case 'hour' :
                    $duration_label_html = sprintf( _n( '%s hour', '%s hours', $duration, 'yith-booking-for-woocommerce' ), $duration );
                    break;
                case 'minute' :
                    $duration_label_html = sprintf( _n( '%s minute', '%s minutes', $duration, 'yith-booking-for-woocommerce' ), $duration );
                    break;
            }
        } else {
            switch ( $product->get_duration_unit() ) {
                case 'month' :
                    $duration_label_html = $duration > 1 ? sprintf( __( '&times; %s months', 'yith-booking-for-woocommerce' ), $duration ) : __( 'Month(s)', 'yith-booking-for-woocommerce' );
                    break;
                case 'week' :
                    $duration_label_html = $duration > 1 ? sprintf( __( '&times; %s weeks', 'yith-booking-for-woocommerce' ), $duration ) : __( 'Week(s)', 'yith-booking-for-woocommerce' );
                    break;
                case 'day' :
                    $duration_label_html = $duration > 1 ? sprintf( __( '&times; %s days', 'yith-booking-for-woocommerce' ), $duration ) : __( 'Day(s)', 'yith-booking-for-woocommerce' );
                    break;
                case 'hour' :
                    $duration_label_html = $duration > 1 ? sprintf( __( '&times; %s hours', 'yith-booking-for-woocommerce' ), $duration ) : __( 'Hour(s)', 'yith-booking-for-woocommerce' );
                    break;
                case 'minute' :
                    $duration_label_html = $duration > 1 ? sprintf( __( '&times; %s minutes', 'yith-booking-for-woocommerce' ), $duration ) : __( 'Minute(s)', 'yith-booking-for-woocommerce' );
                    break;
            }
        }

        $duration_label_html = apply_filters( 'yith_wcbk_booking_form_dates_duration_label_html', $duration_label_html, $product );

        $min = $product->get_min_duration();
        $max = $product->get_max_duration();

        $custom_attributes = "step='1' min='{$min}'";
        $custom_attributes .= $max > 0 ? " max='{$max}'" : '';

        $fields = array(
            array(
                'title'             => __( 'Duration', 'yith-booking-for-woocommerce' ),
                'type'              => !$is_fixed_blocks ? 'number' : 'hidden',
                'id'                => 'yith-wcbk-booking-duration',
                'name'              => 'duration',
                'custom_attributes' => $custom_attributes,
                'value'             => $min,
                'class'             => 'yith-wcbk-booking-duration yith-wcbk-number-minifield',
            ),
        );

        $fields[] = array(
            'type'  => 'html',
            'value' => $duration_label_html,
        );

        $fields_to_print[ 'duration' ] = array(
            'type'             => 'section',
            'section_html_tag' => 'div',
            'class'            => 'yith-wcbk-form-section yith-wcbk-form-section-duration',
            'fields'           => $fields,
        );
    }

    $not_available_date_range = 'day';
    $unit                     = $product->get_duration_unit();

    switch ( $unit ) {
        case 'month' :
            $not_available_date_range = 'month';
            break;
        case 'day' :
            break;
        case 'hour' :
            break;
        case 'minute' :
            break;
    }

    $allow_after      = $product->get_booking_prop( 'allow_after' );
    $allow_after_unit = $product->get_booking_prop( 'allow_after_unit' );

    $after      = '';
    $after_date = time();
    switch ( $allow_after_unit ) {
        case 'month':
            $after      = '+' . $allow_after . 'M';
            $after_date = strtotime( '+' . $allow_after . ' months' );
            break;
        case 'day':
            $after      = '+' . $allow_after . 'D';
            $after_date = strtotime( '+' . $allow_after . ' days' );
            break;
        case 'hour':
            $after      = '+' . $allow_after . 'H';
            $after_date = strtotime( '+' . $allow_after . ' hours' );
            break;

    }

    $current_year  = date( 'Y' );
    $current_month = absint( date( 'm' ) );
    $next_year     = $current_year + 1;
    $next_month    = $current_month;

    $allow_until      = $product->get_booking_prop( 'allow_until' );
    $allow_until_unit = $product->get_booking_prop( 'allow_until_unit' );

    $until     = '';
    $next_date = strtotime( '+ 1 years' );
    switch ( $allow_until_unit ) {
        case 'year':
            $until      = '+' . $allow_until . 'Y';
            $next_date  = strtotime( '+' . $allow_until . ' years' );
            $next_year  = date( 'Y', $next_date );
            $next_month = absint( date( 'm', $next_date ) );
            break;
        case 'month':
            $until      = '+' . $allow_until . 'M';
            $next_date  = strtotime( '+' . $allow_until . ' months' );
            $next_year  = date( 'Y', $next_date );
            $next_month = absint( date( 'm', $next_date ) );
            break;
        case 'day':
            $until      = '+' . $allow_until . 'D';
            $next_date  = strtotime( '+' . $allow_until . ' days' );
            $next_year  = date( 'Y', $next_date );
            $next_month = absint( date( 'm', $next_date ) );
            break;
        case 'hour':
            $until      = '+' . $allow_until . 'H';
            $next_date  = strtotime( '+' . $allow_until . ' hours' );
            $next_year  = date( 'Y', $next_date );
            $next_month = absint( date( 'm', $next_date ) );
            break;

    }

    if ( $unit != 'month' ) {
        $not_available_dates = $product->get_not_available_dates( $current_year, $current_month, $next_year, $next_month, $not_available_date_range );

        $calendar_day_range_picker_class = $product->has_calendar_picker_enabled() ? ' calendar-day-range-picker' : '';

        $fields_to_print[ 'start-date' ] = array(
            'type'             => 'section',
            'section_html_tag' => 'div',
            'class'            => 'yith-wcbk-form-section yith-wcbk-form-section-dates' . $calendar_day_range_picker_class . ' yith-wcbk-has-date-picker',
            'fields'           => array(
                array(
                    'title' => yith_wcbk_get_label( 'start-date' ),
                    'type'  => 'text',
                    'id'    => 'yith-wcbk-booking-start-date-' . $product->get_id(),
                    'name'  => 'from',
                    'class' => 'yith-wcbk-date-picker yith-wcbk-booking-date yith-wcbk-booking-start-date',
                    'data'  => array(
                        'min-date'            => $after,
                        'max-date'            => $until,
                        'not-available-dates' => json_encode( $not_available_dates ),
                        'related-to'          => '#yith-wcbk-booking-end-date-' . $product->get_id(),
                    ),
                    'value' => $product->get_default_start_date()
                ),
            ),
        );

        if ( $product->has_calendar_picker_enabled() ) {
            $not_available_dates_to    = array();
            $not_available_dates_count = count( $not_available_dates );
            if ( $not_available_dates_count > 0 ) {
                $not_available_dates_to = array_map( 'yith_wcbk_add_some_day', $not_available_dates, array_fill( 0, $not_available_dates_count, $product->get_min_duration() ) );
            }

            $fields_to_print[ 'end-date' ] = array(
                'type'             => 'section',
                'section_html_tag' => 'div',
                'class'            => 'yith-wcbk-form-section yith-wcbk-form-section-dates' . $calendar_day_range_picker_class . ' yith-wcbk-has-date-picker',
                'fields'           => array(
                    array(
                        'title' => yith_wcbk_get_label( 'end-date' ),
                        'type'  => 'text',
                        'id'    => 'yith-wcbk-booking-end-date-' . $product->get_id(),
                        'name'  => 'to',
                        'class' => 'yith-wcbk-date-picker yith-wcbk-booking-date yith-wcbk-booking-end-date',
                        'data'  => array(
                            'max-date'            => $until,
                            'not-available-dates' => json_encode( $not_available_dates_to ),
                            'related-from'        => '#yith-wcbk-booking-from-date-' . $product->get_id(),
                        ),
                    ),
                ),
            );
        }
    } else {
        $not_available_months = $product->get_not_available_months( $current_year, $current_month, $next_year, $next_month );

        $fields_to_print[ 'month-picker' ] = array(
            'type'             => 'section',
            'section_html_tag' => 'div',
            'class'            => 'yith-wcbk-form-section yith-wcbk-form-section-dates',
            'fields'           => array(
                array(
                    'title'       => __( 'Start month', 'yith-booking-for-woocommerce' ),
                    'type'        => 'month-picker',
                    'id'          => 'yith-wcbk-booking-start-month-' . $product->get_id(),
                    'name'        => 'from',
                    'class'       => 'yith-wcbk-month-picker',
                    'value_class' => 'yith-wcbk-booking-date yith-wcbk-booking-start-date',
                    'options'     => array(
                        'not_available_months' => $not_available_months,
                        'min_date'             => $after_date,
                        'max_date'             => $next_date,
                    ),
                ),
            ),
        );
    }
    YITH_WCBK_Printer()->print_fields( $fields_to_print );
    ?>
</div>
