<?php
/**
 * Booking form services
 *
 * @author        Leanza Francesco <leanzafrancesco@gmail.com>
 *
 * @var WC_Product_Booking $product
 */

if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

if ( $product->has_services() ) {
    $services = $product->get_services();
    if ( !!$services && is_array( $services ) ) {

        $services_to_display = array();
        $included_services   = array();

        foreach ( $services as $service_id ) {
            $service = yith_get_booking_service( $service_id );

            if ( !$service->is_valid() || $service->is_hidden() )
                continue;

            if ( $service->is_optional() ) {
                $services_to_display[] = $service;
            } else {
                $included_services[] = $service;
            }
        }

        $services_to_display = array_merge( $services_to_display, $included_services );

        foreach ( $services_to_display as $service ) {
            /**
             * @var YITH_WCBK_Service $service
             */
            $type = 'hidden';

            if ( $service->is_optional() ) {
                $type = 'checkbox';
            }

            $fields = array(
                'title'          => $service->get_name(),
                'type'           => $type,
                'id'             => "yith-wcbk-booking-services-{$service->id}",
                'name'           => "booking_services[]",
                'checkbox_value' => $service->id,
                'value'          => 'no',
                'class'          => 'yith-wcbk-booking-service',
                'data'           => array(
                    'service-id' => $service->id,
                ),
            );

            if ( YITH_WCBK()->settings->get( 'show-service-prices', 'no' ) === 'yes' ) {
                $help_tip = '';
                if ( $service->is_multiply_per_persons() ) {
                    if ( $product->has_person_types() ) {
                        foreach ( $product->get_person_types() as $person_type ) {
                            /**
                             * @var bool $enabled
                             * @var int  $id
                             * @var int  $min
                             * @var int  $max
                             * @var int  $base_cost
                             * @var int  $block_cost
                             */
                            extract( $person_type );

                            if ( !$person_type[ 'enabled' ] )
                                continue;

                            $person_type_id = absint( $person_type[ 'id' ] );
                            $price          = $service->get_price( $person_type_id );
                            if ( !$price ) {
                                $price = __( 'Free', 'yith-booking-for-woocommerce' );
                            } else {
                                $price = get_woocommerce_currency_symbol() . ' ' . number_format( $service->get_price( $person_type_id ), wc_get_price_decimals(), wc_get_price_decimal_separator(), wc_get_price_thousand_separator() );
                                if ( $service->is_multiply_per_blocks() ) {
                                    $price .= ' / ' . $product->get_block_duration_html();
                                }
                            }

                            $help_tip .= YITH_WCBK()->person_type_helper->get_person_type_title( $person_type_id ) . ': ' . $price . '<br />';
                        }
                    } else {
                        $price = $service->get_price();
                        if ( !$price ) {
                            $price = __( 'Free', 'yith-booking-for-woocommerce' );
                        } else {
                            $price = get_woocommerce_currency_symbol() . ' ' . number_format( $service->get_price(), wc_get_price_decimals(), wc_get_price_decimal_separator(), wc_get_price_thousand_separator() );
                            if ( $service->is_multiply_per_blocks() ) {
                                $price .= ' / ' . $product->get_block_duration_html();
                            }
                        }

                        $help_tip .= $price;
                    }
                } else {
                    $price = $service->get_price();
                    if ( !$price ) {
                        $price = __( 'Free', 'yith-booking-for-woocommerce' );
                    } else {
                        $price = get_woocommerce_currency_symbol() . ' ' . number_format( $service->get_price(), wc_get_price_decimals(), wc_get_price_decimal_separator(), wc_get_price_thousand_separator() );
                        if ( $service->is_multiply_per_blocks() ) {
                            $price .= ' / ' . $product->get_block_duration_html();
                        }
                    }
                    $help_tip .= $price;
                }

                if ( $help_tip ) {
                    $fields[ 'help_tip' ] = $help_tip;
                }
            }

            YITH_WCBK_Printer()->print_field( array(
                                                  'type'             => 'section',
                                                  'section_html_tag' => 'div',
                                                  'class'            => 'yith-wcbk-form-section yith-wcbk-form-section-services',
                                                  'fields'           => array( $fields ),
                                              ) );

        }
    }

}

?>